@@ -9,7 +9,7 @@
 #ifndef __XML_LIBXML_H__
 #define __XML_LIBXML_H__
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(__CYGWIN__)
 #include "win32config.h"
 #else
 #include "config.h"
